@@ -1,23 +1,10 @@
-/* ****************************************************************************
-  This file is part of the game 'KJumpingCube'
+/*
+    This file is part of the game 'KJumpingCube'
 
-  Copyright (C) 2012 by Ian Wadham <iandw.au@gmail.com>
+    SPDX-FileCopyrightText: 2012 Ian Wadham <iandw.au@gmail.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
-**************************************************************************** */
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "ai_main.h"
 #include "ai_kepler.h"
@@ -94,10 +81,6 @@ void makeRandomSequence (int nMax, int * seq, QRandomGenerator & random)
       seq[last] = temp;
    }
    return;
-   for (int n = 0; n < nMax; n++) {
-      fprintf (stderr, " %d", seq[n]);
-   }
-   fprintf (stderr, "\n");
 }
 
 AI_Main::AI_Main (QObject * parent, int side)
